// packages/@code-like-a-carpenter/foundation-parser/src/paths.ts
import fs from "node:fs";
import path from "node:path";
import { assert } from "@code-like-a-carpenter/assert";
function resolveActionsModuleId(config, directory) {
  if (config.actionsModuleId.startsWith(".")) {
    const importPath = path.relative(directory, config.actionsModuleId);
    if (config.requireExtensions) {
      assert(
        path.extname(importPath),
        `Expected ${importPath} to actionsModuleId to have an extension in file`
      );
    }
    return importPath;
  }
  return config.actionsModuleId;
}
function resolveDependenciesModuleId(config, directory) {
  if (config.dependenciesModuleId.startsWith(".")) {
    const importPath = path.relative(directory, config.dependenciesModuleId);
    if (config.requireExtensions) {
      assert(
        path.extname(importPath),
        `Expected ${importPath} to dependenciesModuleId to have an extension`
      );
    }
    return importPath;
  }
  return config.dependenciesModuleId;
}
function resolveHandlerModuleId(config, type, directory, handler) {
  if (!handler.startsWith(".")) {
    return handler;
  }
  assert(type.astNode, `Expected ${type.name} to have an AST node`);
  assert(
    type.astNode.description,
    `Expected ${type.name} to have a description`
  );
  assert(
    type.astNode.description.loc,
    `Expected ${type.name} to have a location`
  );
  assert(
    type.astNode.description.loc.source,
    `Expected ${type.name} to have a source`
  );
  assert(
    type.astNode.description.loc.source.name,
    `Expected ${type.name} to have a name`
  );
  const schemaFile = type.astNode.description.loc.source.name;
  if (process.env.NODE_ENV !== "test") {
    assert(fs.statSync(schemaFile), `Expected ${schemaFile} to exist`);
  }
  const absolutePathToHandler = path.join(path.dirname(schemaFile), handler);
  const absolutePathToDirectory = path.resolve(directory);
  const importPath = path.relative(
    absolutePathToDirectory,
    absolutePathToHandler
  );
  if (config.requireExtensions) {
    assert(
      path.extname(importPath),
      `Expected ${importPath} to have an extension in file ${schemaFile}`
    );
  }
  return importPath;
}
export {
  resolveActionsModuleId,
  resolveDependenciesModuleId,
  resolveHandlerModuleId
};
//# sourceMappingURL=paths.mjs.map
